OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Нууц үг буруу",
    "Authentication error" : "Нотолгооны алдаа",
    "Your full name has been changed." : "Таны бүтэн нэр солигдлоо.",
    "Unable to change full name" : "Бүтэн нэр солих боломжгүй байна",
    "Sharing" : "Түгээлт",
    "Cron" : "Крон",
    "Log" : "Лог бичилт",
    "Couldn't remove app." : "Апп-ыг устгаж чадсангүй",
    "Language changed" : "Хэл солигдлоо",
    "Invalid request" : "Буруу хүсэлт",
    "Admins can't remove themself from the admin group" : "Админууд өөрсдийгөө Админ бүлгээс хасаж чадахгүй",
    "All" : "Бүгд",
    "Email" : "И-мэйл",
    "Password" : "Нууц үг",
    "Username" : "Хэрэглэгчийн нэр",
    "Done" : "Болсон"
},
"nplurals=2; plural=(n != 1);");
